@@ -136,7 +136,7 @@ class DatastoreAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -397,7 +397,7 @@ class DatastoreAsyncClient:
         Returns:
             google.cloud.datastore_v1.types.RunQueryResponse:
                 The response for
-                [Datastore.RunQuery][google.datastore.v1.Datastore.RunQuery].
+                   [Datastore.RunQuery][google.datastore.v1.Datastore.RunQuery].
 
         """
         # Create or coerce a protobuf request object.
@@ -489,7 +489,7 @@ class DatastoreAsyncClient:
         Returns:
             google.cloud.datastore_v1.types.RunAggregationQueryResponse:
                 The response for
-                [Datastore.RunAggregationQuery][google.datastore.v1.Datastore.RunAggregationQuery].
+                   [Datastore.RunAggregationQuery][google.datastore.v1.Datastore.RunAggregationQuery].
 
         """
         # Create or coerce a protobuf request object.
@@ -589,7 +589,7 @@ class DatastoreAsyncClient:
         Returns:
             google.cloud.datastore_v1.types.BeginTransactionResponse:
                 The response for
-                [Datastore.BeginTransaction][google.datastore.v1.Datastore.BeginTransaction].
+                   [Datastore.BeginTransaction][google.datastore.v1.Datastore.BeginTransaction].
 
         """
         # Create or coerce a protobuf request object.
@@ -852,7 +852,8 @@ class DatastoreAsyncClient:
 
         Returns:
             google.cloud.datastore_v1.types.RollbackResponse:
-                The response for [Datastore.Rollback][google.datastore.v1.Datastore.Rollback].
+                The response for
+                   [Datastore.Rollback][google.datastore.v1.Datastore.Rollback].
                    (an empty message).
 
         """
@@ -970,7 +971,7 @@ class DatastoreAsyncClient:
         Returns:
             google.cloud.datastore_v1.types.AllocateIdsResponse:
                 The response for
-                [Datastore.AllocateIds][google.datastore.v1.Datastore.AllocateIds].
+                   [Datastore.AllocateIds][google.datastore.v1.Datastore.AllocateIds].
 
         """
         # Create or coerce a protobuf request object.
@@ -1086,7 +1087,7 @@ class DatastoreAsyncClient:
         Returns:
             google.cloud.datastore_v1.types.ReserveIdsResponse:
                 The response for
-                [Datastore.ReserveIds][google.datastore.v1.Datastore.ReserveIds].
+                   [Datastore.ReserveIds][google.datastore.v1.Datastore.ReserveIds].
 
         """
         # Create or coerce a protobuf request object.
