@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import DatastoreTransport
 from .grpc import DatastoreGrpcTransport
 from .grpc_asyncio import DatastoreGrpcAsyncIOTransport
+from .rest import DatastoreRestTransport
+from .rest import DatastoreRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[DatastoreTransport]]
 _transport_registry["grpc"] = DatastoreGrpcTransport
 _transport_registry["grpc_asyncio"] = DatastoreGrpcAsyncIOTransport
+_transport_registry["rest"] = DatastoreRestTransport
 
 __all__ = (
     "DatastoreTransport",
     "DatastoreGrpcTransport",
     "DatastoreGrpcAsyncIOTransport",
+    "DatastoreRestTransport",
+    "DatastoreRestInterceptor",
 )
