@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 import proto  # type: ignore
@@ -371,8 +373,8 @@ class Entity(proto.Message):
             The entity's properties. The map's keys are property names.
             A property name matching regex ``__.*__`` is reserved. A
             reserved property name is forbidden in certain documented
-            contexts. The name must not contain more than 500
-            characters. The name cannot be ``""``.
+            contexts. The map keys, represented as UTF-8, must not
+            exceed 1,500 bytes and cannot be empty.
     """
 
     key: "Key" = proto.Field(
