@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 import proto  # type: ignore
@@ -60,6 +62,12 @@ class EntityResult(proto.Message):
             entities in ``LookupResponse``, this is the version of the
             snapshot that was used to look up the entity, and it is
             always set except for eventually consistent reads.
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            The time at which the entity was created. This field is set
+            for
+            [``FULL``][google.datastore.v1.EntityResult.ResultType.FULL]
+            entity results. If this entity is missing, this field will
+            not be set.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which the entity was last changed. This field is
             set for
@@ -105,6 +113,11 @@ class EntityResult(proto.Message):
         proto.INT64,
         number=4,
     )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
     update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -133,10 +146,16 @@ class Query(proto.Message):
             The order to apply to the query results (if
             empty, order is unspecified).
         distinct_on (MutableSequence[google.cloud.datastore_v1.types.PropertyReference]):
-            The properties to make distinct. The query
-            results will contain the first result for each
-            distinct combination of values for the given
-            properties (if empty, all results are returned).
+            The properties to make distinct. The query results will
+            contain the first result for each distinct combination of
+            values for the given properties (if empty, all results are
+            returned).
+
+            Requires:
+
+            -  If ``order`` is specified, the set of distinct on
+               properties must appear before the non-distinct on
+               properties in ``order``.
         start_cursor (bytes):
             A starting point for the query results. Query cursors are
             returned in query result batches and `can only be used to
@@ -225,7 +244,7 @@ class AggregationQuery(proto.Message):
     """
 
     class Aggregation(proto.Message):
-        r"""Defines a aggregation that produces a single result.
+        r"""Defines an aggregation that produces a single result.
 
         .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
 
@@ -248,7 +267,7 @@ class AggregationQuery(proto.Message):
                      COUNT_UP_TO(1) AS count_up_to_1,
                      COUNT_UP_TO(2),
                      COUNT_UP_TO(3) AS count_up_to_3,
-                     COUNT_UP_TO(4)
+                     COUNT(*)
                    OVER (
                      ...
                    );
@@ -261,7 +280,7 @@ class AggregationQuery(proto.Message):
                      COUNT_UP_TO(1) AS count_up_to_1,
                      COUNT_UP_TO(2) AS property_1,
                      COUNT_UP_TO(3) AS count_up_to_3,
-                     COUNT_UP_TO(4) AS property_2
+                     COUNT(*) AS property_2
                    OVER (
                      ...
                    );
@@ -285,7 +304,7 @@ class AggregationQuery(proto.Message):
                     entities to count.
 
                     This provides a way to set an upper bound on the number of
-                    entities to scan, limiting latency and cost.
+                    entities to scan, limiting latency, and cost.
 
                     Unspecified is interpreted as no bound.
 
@@ -474,9 +493,13 @@ class CompositeFilter(proto.Message):
             AND (1):
                 The results are required to satisfy each of
                 the combined filters.
+            OR (2):
+                Documents are required to satisfy at least
+                one of the combined filters.
         """
         OPERATOR_UNSPECIFIED = 0
         AND = 1
+        OR = 2
 
     op: Operator = proto.Field(
         proto.ENUM,
@@ -560,6 +583,7 @@ class PropertyFilter(proto.Message):
                 Requires:
 
                 -  That ``value`` is an entity key.
+                -  No other ``HAS_ANCESTOR`` is in the same query.
             NOT_IN (13):
                 The value of the ``property`` is not in the given array.
 
